@@ -182,6 +182,8 @@ class SchemaNode:
     def definition_name(self) -> str:
         if self.ref_path:
             return self.ref_path.split("/")[-1]
+        if self.title:
+            return self.title
         return ""
 
     @property
@@ -458,7 +460,9 @@ class SchemaNode:
 
 
 def build_intermediate_representation(
-    schema_path: Union[str, TextIO], config: GenerationConfiguration, loaded_schemas: Optional[Dict[str, Any]] = None,
+    schema_path: Union[str, TextIO],
+    config: GenerationConfiguration,
+    loaded_schemas: Optional[Dict[str, Any]] = None,
 ) -> SchemaNode:
     """Build a SchemaNode object representing a JSON schema with added metadata to help rendering as a documentation.
 
